@@ -20,6 +20,16 @@ class DataFrameUploadFailedException(Exception):
         self.data = data
 
 
+class DataFrameUploadValidationException(Exception):
+    pass
+
+
+class DatasetInfoFailedException(Exception):
+    def __init__(self, message, data):
+        self.message = message
+        self.data = data
+
+
 class SchemaGenerationFailedException(Exception):
     def __init__(self, message, data):
         self.message = message
@@ -42,3 +52,7 @@ class AuthenticationErrorException(Exception):
 
 class SchemaInitialisationException(Exception):
     pass
+
+
+class ColumnNotDifferentException(Exception):
+    pass
